@@ -64,7 +64,8 @@ void usage(void)
 		"               [--membind=nodes] [--localalloc] command args ...\n"
 		"       numactl [--show]\n"
 		"       numactl [--hardware]\n"
-		"       numactl [--length length] [--offset offset] [--shmmode shmmode] [--strict]\n"
+		"       numactl [--length length] [--offset offset] [--shmmode shmmode]\n"
+		"               [--strict]\n"
 		"               --shm shmkeyfile | --file tmpfsfile | --shmid id\n"
 		"               [--huge] [--touch]\n" 
 		"               memory policy\n"
